function PR.GUI.RefreshSectorBox()
    -- make sure we got asteroid data to work with
    if PR.GUI.DisplayedSector == 0 or
        (PR.GUI.DisplayedSector ~= PR.LoadedSector)
    then
        if PR.GUI.DisplayedSector == 0 then
            PR.GUI.DisplayedSector = PR.Sector
        end
        PR.LoadSector(PR.GUI.DisplayedSector)
        PR.GUI.SectorOres = PR.GetSectorOres()
        if not PR.GUI.SectorOres then PR.GUI.OreSort = 0
        elseif PR.GUI.OreSort == 0 or PR.GUI.OreSort > PR.GUI.SectorOres.n then
            PR.GUI.OreSort = 1
        end
        -- fill PR.GUI.SectorList
        PR.GUI.SectorRoidList = {}
        for roidId, _roidData in pairs(PR.Data.RoidList) do
            -- create a copy of the _roidData table so we can add some fields
            -- without affecting the referenced PR.Data table
            local roidData = {}
            for key, val in pairs(_roidData) do
                roidData[key] = val
            end
            roidData.Id = roidId
            roidData.XPV = PR.GetXPV(roidData)
            roidData.Value = roidData.Pt and
                math.floor(roidData.Pt * roidData.XPV * 0.01) or 0
            table.insert(PR.GUI.SectorRoidList, roidData)
        end
    end

    -- update buttons
    PR.GUI.Btn_Top1.title = AbbrLocationStr(PR.GUI.DisplayedSector)
    PR.GUI.Btn_Top2.title = PR.Config.SectorSort
    PR.GUI.Btn_Top2.tooltip = "Sort mode"
    PR.GUI.Btn_Top3.tooltip = PR.Config.SectorSort == "ByOre" and
        "Ore to sort by" or "Sector scan completion rate"
    PR.GUI.Btn_Bottom3.title = "Reset Sector"
    PR.GUI.Btn_Bottom3.tooltip = "Reset all ore data for the current sector"
    if PR.GUI.DisplayedSector ~= PR.Sector then
        if NavRoute.GetFinalDestination() == PR.GUI.DisplayedSector then
            PR.GUI.Btn_Top4.title = "NavRoute set"
            PR.GUI.Btn_Top4.fgcolor = PR.GUI.Color.Green
        else
            PR.GUI.Btn_Top4.title = "Set NavRoute"
            PR.GUI.Btn_Top4.fgcolor = PR.GUI.Color.Button
        end
    elseif PR.GUI.DisplayedSector == PR.Sector then
        if PR.SingleSearchTarget > 0 then
            PR.GUI.Btn_Top4.fgcolor = PR.GUI.Color.Red
            PR.GUI.Btn_Top4.title = "Stop Search"
        elseif PR.MiningBeamEquipped then
            if PR.GUI.ScanTop30Idx then
                PR.GUI.Btn_Top4.title = "Stop Top30 Check"
                PR.GUI.Btn_Top4.fgcolor = PR.GUI.Color.Red
            else
                PR.GUI.Btn_Top4.title = "Start Top30 Check"
                PR.GUI.Btn_Top4.fgcolor = PR.GUI.Color.Button
            end
        end
    end

    -- if this sector has no scanned ores, abort here
    if not next(PR.Data.RoidList) then return end

    -- update buttons (cont.)
    if PR.Config.SectorSort == "ByOre" then
        if PR.GUI.OreSort > 0 then
            PR.GUI.Btn_Top3.title = PR.GUI.SectorOres[PR.GUI.OreSort].name
        end
    else
        -- set completion percentage to third button
        PR.GUI.Btn_Top3.title = "@ " ..
            math.floor((PR.Data.MaxId - PR.Data.Unscanned) /
                PR.Data.MaxId * 1000) / 10 .. "%"
    end

    -- sort PR.Data.RoidList
    local sort_field
    if PR.Config.SectorSort == "ById" then
        sort_field = "Id"
    elseif PR.Config.SectorSort == "ByXPV" then
        sort_field = "XPV"
    elseif PR.Config.SectorSort == "ByMass" then
        sort_field = "Pt"
    elseif PR.Config.SectorSort == "ByValue" then
        sort_field = "Value"
    elseif PR.Config.SectorSort == "ByOre" then
        sort_field = PR.GUI.SectorOres[PR.GUI.OreSort].shortname
    end
    if sort_field == "Id" then
        -- sorting by Id is ascending
        table.sort(PR.GUI.SectorRoidList, function(a, b) return a.Id < b.Id end)
    else
        -- sort everything else descending
        table.sort(PR.GUI.SectorRoidList, function(a, b)
            if a[sort_field] == b[sort_field] then
                if a.XPV == b.XPV then return (a.Pt or 0) > (b.Pt or 0)
                else return a.XPV > b.XPV
                end
            end
            if not a[sort_field] then return false end
            if not b[sort_field] then return true end
            return a[sort_field] > b[sort_field]
        end)
    end

    -- display the list
    local item_count = #PR.GUI.SectorRoidList
    PR.GUI.DisplayPanel.numlin = item_count
    PR.GUI.ListedItems = {}
    -- just in case, had the loaded sector change once between above and here:
    PR.LoadSector(PR.GUI.DisplayedSector)
    for i = 1, item_count do
        local roidId = PR.GUI.SectorRoidList[i].Id
        local value = PR.FormatId(roidId) .. ": " ..
            PR.FormatOreData(PR.Data.RoidList[roidId])
        if PR.Config.SectorSort == "ByValue" then
            value = value ..
                "  Value: " .. (PR.GUI.SectorRoidList[i].Value > 0 and
                    comma_value(PR.GUI.SectorRoidList[i].Value) or "?")
        else
            value = value ..
                "  XPV: " .. comma_value(PR.GUI.SectorRoidList[i].XPV)
            -- show mass if we have it or are sorting ByMass
            if PR.GUI.SectorRoidList[i].Pt or PR.Config.SectorSort == "ByMass" then
                value = value ..
                    PR.Color.LightGray .. "  Mass: " ..
                    (PR.GUI.SectorRoidList[i].Pt and
                        (comma_value(PR.GUI.SectorRoidList[i].Pt .. " Pt")) or
                        "?") .. PR.Color.TERMINATOR
            end
        end
        PR.GUI.ListedItems[i] = roidId
        PR.GUI.DisplayPanel:setcell(i, 1, value)
    end
    PR.GUI.MaxDisplayRows = item_count
end

function PR.GUI.GetSectorOreIndex(orename)
    for i = 1, PR.GUI.SectorOres.n do
        if PR.GUI.SectorOres[i].name == orename then
            return i
        end
    end
    return 0
end

function PR.GUI.ScanTop30()
    PR.GUI.ScanTop30Idx = PR.GUI.ScanTop30Idx and
        (PR.GUI.ScanTop30Idx + 1) or 1
    local dist
    for i = PR.GUI.ScanTop30Idx, math.min(#PR.GUI.SectorRoidList, 30) do
        if not PR.GUI.ScanTop30Idx then return end
        local targetId = PR.GUI.SectorRoidList[i].Id
        PR.GUI.ScanTop30Idx = i
        dist = PR.TryToTarget(targetId)
        if dist then return end
    end
    PR.GUI.ScanTop30Idx = false
end
