function PR.GUI.RefreshUniverseBox()
    PR.GUI.Btn_Top2.title = PR.Config.UniverseSort
    PR.GUI.Btn_Top2.tooltip = "Sort mode"
    PR.LoadAllSystemData(PR.GUI.SystemData)
    if PR.Config.UniverseSort == "ByOre" then PR.GUI.ShowUniverseByOre()
    elseif PR.Config.UniverseSort == "BySystem" then PR.GUI.ShowUniverseBySystem()
    end
end

function PR.GUI.ShowUniverseByOre()
    local systemoretable = {}
    for sysid = 1, PR.SystemOwnership.n do
        if PR.GUI.SystemData[sysid] then
            for i = 1, PR.Ore.n do
                if PR.GUI.SystemData[sysid][PR.Ore[i].shortname] then
                    if not systemoretable[PR.Ore[i].shortname] then
                        systemoretable[PR.Ore[i].shortname] = {}
                    end
                    local orecount = PR.GetOreCountInSystem(
                        PR.GUI.SystemData[sysid][PR.Ore[i].shortname])
                    if orecount > 0 then
                        table.insert(systemoretable[PR.Ore[i].shortname],
                            { PR.Color.FactionColors[ PR.SystemOwnership[sysid] ] ..
                                PR.GUI.SystemData[sysid].systemname ..
                                PR.Color.LightGray .. " (" .. orecount .. ")" ..
                                PR.Color.TERMINATOR, sysid }
                        )
                    end
                end
            end
        end
    end

    PR.GUI.ListedItems = {}
    local row = 1
    for i = 1, PR.Ore.n do
        PR.GUI.DisplayPanel[row] = "\t" .. PR.Ore[i].color .. PR.Ore[i].name
        local shortore = PR.Ore[i].shortname
        if not systemoretable[shortore] then
            row = row + 1
            PR.GUI.DisplayPanel[row] = "(no known systems)"
        else
            table.sort(systemoretable[shortore],
                function(a, b) return a[1] < b[1] end)
            -- horizontal listing (would need horizontal scroll bar):
            --PR.GUI.DisplayPanel[row] = table.concat(systemoretable[shortore], "\n")
            -- vertical listing:
            for idx = 1, #systemoretable[shortore] do
                row = row + 1
                PR.GUI.DisplayPanel[row] = systemoretable[shortore][idx][1]
                PR.GUI.ListedItems[row] = { ore = shortore,
                    system = systemoretable[shortore][idx][2] }
            end
        end
        row = row + 2
    end
    PR.GUI.MaxDisplayRows = row - 2
    PR.GUI.ListToMatrix()
end

function PR.GUI.ShowUniverseBySystem()
    local row = 1
    for x = 1, PR.Systems.n do
        local sysid = PR.Systems[x][1]
        if PR.GUI.SystemData[sysid] then
            local orelist = {}
            for i = 1, PR.Ore.n do
                if PR.GUI.SystemData[sysid][PR.Ore[i].shortname] then
                    local orecount = PR.GetOreCountInSystem(
                        PR.GUI.SystemData[sysid][PR.Ore[i].shortname])
                    if orecount > 0 then
                        table.insert(orelist, PR.Ore[i].color ..
                            PR.Ore[i].shortname .. PR.Color.TERMINATOR ..
                            PR.Color.LightGray .. " (" .. orecount .. ")" ..
                            PR.Color.TERMINATOR)
                    end
                end
            end
            orelist.n = #orelist
            if orelist.n > 0 then
                PR.GUI.DisplayPanel[row] = PR.Color.FactionColors[ PR.SystemOwnership[sysid] ] ..
                    PR.GUI.SystemData[sysid].systemname .. PR.Color.TERMINATOR
                row = row + 1
                local counter = 0
                --PR.GUI.DisplayPanel[row] = table.concat(orelist, " - ")
                -- horizontal view but with a line break after listing 6 ores to prevent
                -- it from becoming too wide
                for i = 1, orelist.n do
                    if counter > 7 then
                        PR.GUI.DisplayPanel[row] = PR.GUI.DisplayPanel[row]:sub(1, -4)
                        row = row + 1
                        counter = 0
                    end
                    PR.GUI.DisplayPanel[row] = (PR.GUI.DisplayPanel[row] or "") ..
                        orelist[i] .. " - "
                    counter = counter + 1
                end
                if counter > 0 then
                    PR.GUI.DisplayPanel[row] = PR.GUI.DisplayPanel[row]:sub(1, -4)
                end
                row = row + 2
            end
        end
    end
    PR.GUI.MaxDisplayRows = row - 2
    PR.GUI.ListToMatrix()
end
