-- load RoidDB roid data
local function loadRoidDBData()
    local success, notesid = pcall(function() return roiddb.notesid end)
    if not success then notesid = 764332 end
    return unspickle(LoadSystemNotes(notesid))
end

local function importRoidDBData(RoidDB_data)
    local imported = 0
    local skipped = 0
    local failed = 0
    for sectorId, RoidDB_sectorData in pairs(RoidDB_data) do
        -- load PR data for the same sector
        local sectorData = PR.LoadSectorData(sectorId)
        local sectorChanged = false
        if not sectorData.RoidList then sectorData.RoidList = {} end
        for roidId, RoidDB_RoidData in pairs(RoidDB_sectorData) do
            local roidData = sectorData.RoidList[roidId]
            if roidData then
                -- skip asteroids we already know about
                skipped = skipped + 1
            else
                roidData = {}
                for name, percentage in pairs(RoidDB_RoidData) do
                    local shortname = PR.GetOreNameShort(name)
                    if shortname == name then
                        failed = failed + 1
                    else
                        roidData[shortname] = tonumber(percentage)
                    end
                end
                imported = imported + 1
                sectorChanged = true
            end
            if sectorChanged then sectorData.RoidList[roidId] = roidData end
        end
        -- save PR sector data if something was imported
        if sectorChanged then
            PR.SaveSectorData(sectorId, sectorData)
        end
    end
    return imported, skipped, failed
end

-- import new data from RoidDB db
function PR.Interop.ImportFromRoidDB()
    PR.Interop.Import("RoidDB", loadRoidDBData, importRoidDBData)
end
