local getTargetInfo = GetTargetInfo
local getRadarSelectionID = radar.GetRadarSelectionID

-- returns target distance if current target is Asteroid or Ice Crystal
-- cannot identify by node because "Asteroid Debris" shares the node
function PR.TargetIsRoid()
    local name, _, dist = getTargetInfo()
    if name == "Asteroid" or name == "Ice Crystal" then
        if PR.RoidNode == 0 then PR.RoidNode = getRadarSelectionID() end
        return dist
    end
end

-- true if RoidId is in database for current sector
function PR.IsScanned(roidId)
    return PR.Data.RoidList[roidId] ~= nil
end

-- true if ore data differs between stored data for RoidId and the provided RoidTable
function PR.HasOreChanged(roidTable)
    for i = 1, PR.Ore.n do
        if roidTable[PR.Ore[i].shortname] ~=
            PR.Data.RoidList[roidTable.Id][PR.Ore[i].shortname] then
            return true
        end
    end
    return false
end

-- return XPV for given asteroid data
function PR.GetXPV(roidTable)
    local XPV = 0
    for i = 1, PR.Ore.n do
        local percent = roidTable[PR.Ore[i].shortname] or 0
        XPV = XPV + percent * PR.Ore[i].xp
    end
    return XPV
end

-- return known mass or nil for given asteroid id
function PR.GetMass(roidId)
    if PR.IsScanned(roidId) then
        return PR.Data.RoidList[roidId].Pt or 0
    end
    return 0
end

-- gets single asteroid data from database but keeps mass supplied in roidTable
function PR.GetRoidAddMass(sectorId, roidTable)
    local mass = roidTable.Pt
    if PR.IsScanned(roidTable.Id) then
        roidTable = PR.GetRoid(sectorId, roidTable.Id)
    end
    -- restore measured mass, if any
    if mass then roidTable.Pt = mass end
    return roidTable
end

-- get single asteroid from database
function PR.GetRoid(sectorId, roidId)
    PR.LoadSector(sectorId)
    -- get roid data from database
    local _roidData = PR.Data.RoidList[roidId] or {}
    -- create a copy so we do not manipulate the database directly
    local roidData = {}
    for key, val in pairs(_roidData) do
        roidData[key] = val
    end
    roidData.Id = roidId -- add Id field, makes handling easier
    return roidData
end

-- saves single roid to database
function PR.SetRoid(sectorId, roidTable)
    PR.LoadSector(sectorId)
    if not PR.Data.RoidList[roidTable.Id] then PR.Data.RoidList[roidTable.Id] = {} end
    for key, val in pairs(roidTable) do
        if key ~= 0 and key ~= "Id" and val ~= 0 then
            PR.Data.RoidList[roidTable.Id][key] = val
        end
    end
    PR.SaveSector()
end
