function PR.FormatId(roidId) -- add leading zeroes
    roidId = tonumber(roidId)
    return roidId and string.format("#%0" .. PR.MaxIdDigits .. "d", roidId) or "---"
end

function PR.FormatOreData(roidTable)
    local orestring = ""
    if roidTable then
        for i = 1, PR.Ore.n do
            local percentage = roidTable[PR.Ore[i].shortname] or 0
            if percentage > 0 then
                orestring = orestring .. " " .. PR.Ore[i].color ..
                    PR.Ore[i].shortname .. ": " ..
                    string.format("%.1f", percentage) .. " " ..
                    PR.Color.TERMINATOR
            end
        end
    end
    return orestring
end

function PR.DisplayScanData(roidTable, is_new, ore_changed)
    if (is_new or ore_changed or roidTable.Id ~= PR.LastDisplayedRoidId) then
        PR.LastDisplayedRoidId = roidTable.Id
        -- format scan data
        local msg = "Asteroid " .. PR.FormatId(roidTable.Id)
        local XPV = PR.GetXPV(roidTable)
        if XPV ~= 0 then
            if XPV > PR.Config.MinXPV then
                -- valid asteroid, display scan data
                msg = PR.Color.White .. msg .. ": " .. PR.FormatOreData(roidTable)
                local mass = PR.GetMass(roidTable.Id)
                msg = msg .. PR.Color.White .. "  XPV: " .. XPV
                if mass > 0 then
                    msg = msg .. PR.Color.LightGray .. "  Mass: " .. mass .. " Pt"
                end
            else
                -- junk asteroid, don't display scan data, and if not fully
                -- verbose nothing at all except if newly scanned
                if not is_new and (PR.Config.VerbosityLevel < 3) then return end
                msg = PR.Color.White .. msg .. " is junk" -- @ " .. dist .. "m"
            end
        else
            -- unscanned asteroid
            local dist = comma_value(math.floor(GetTargetDistance() or 0))
            msg = PR.Color.Gold .. msg .. " is unscanned @ " .. dist .. "m"
        end

        if is_new then
            msg = PR.Color.Gold .. "New asteroid scanned: " .. PR.Color.TERMINATOR .. msg
        elseif ore_changed then
            msg = PR.Color.Red .. "Asteroid composition changed: " .. PR.Color.TERMINATOR .. msg
        end
        PR.Print(msg .. PR.Color.TERMINATOR)
    end
end
